package VMOMI::ConfigSpecOperation;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
